Package: visNetwork
Title: Network Visualization using 'vis.js' Library
Version: 2.0.4
Date: 2018-06-13
Authors@R: c(
    person(family = "Almende B.V.", role = c("aut", "cph"),
       comment = "vis.js library in htmlwidgets/lib, http://visjs.org, http://www.almende.com/home"),
    person("Benoit", "Thieurmel", role = c("aut", "cre"),
       comment = "R interface", email = "benoit.thieurmel@datastorm.fr"),
    person(given = "Titouan", family = "Robert", 
    email = "titouan.robert@datastorm.fr", role = c("aut", "ctb"))
    )
Maintainer: Benoit Thieurmel <benoit.thieurmel@datastorm.fr>
Description: Provides an R interface to the 'vis.js' JavaScript charting
    library. It allows an interactive visualization of networks.
BugReports: https://github.com/datastorm-open/visNetwork/issues
URL: http://datastorm-open.github.io/visNetwork/
Depends: R (>= 3.0)
Imports: htmlwidgets, htmltools, jsonlite, magrittr, utils, methods,
        grDevices, stats
License: MIT + file LICENSE
Suggests: knitr, rmarkdown, webshot, igraph, rpart, shiny,
        shinyWidgets, colourpicker, sparkline, ggraph, flashClust
VignetteBuilder: knitr, rmarkdown, webshot
RoxygenNote: 6.0.1
NeedsCompilation: no
Packaged: 2018-06-14 07:23:11 UTC; Datastorm
Author: Almende B.V. [aut, cph] (vis.js library in htmlwidgets/lib,
    http://visjs.org, http://www.almende.com/home),
  Benoit Thieurmel [aut, cre] (R interface),
  Titouan Robert [aut, ctb]
Repository: CRAN
Date/Publication: 2018-06-14 08:23:00 UTC
Built: R 3.4.1; ; 2018-09-09 22:25:45 UTC; windows
