# Generated by roxygen2: do not edit by hand

export("%>%")
export(addExport)
export(addFontAwesome)
export(addIonicons)
export(renderVisNetwork)
export(toVisNetworkData)
export(visClusteringByColor)
export(visClusteringByConnection)
export(visClusteringByGroup)
export(visClusteringByHubsize)
export(visClusteringOutliers)
export(visConfigure)
export(visDocumentation)
export(visEdges)
export(visEvents)
export(visExport)
export(visFit)
export(visFocus)
export(visGetEdges)
export(visGetNodes)
export(visGetPositions)
export(visGroups)
export(visHierarchicalLayout)
export(visIgraph)
export(visIgraphLayout)
export(visInteraction)
export(visLayout)
export(visLegend)
export(visMoveNode)
export(visNearestNodes)
export(visNetwork)
export(visNetworkOutput)
export(visNetworkProxy)
export(visNodes)
export(visOptions)
export(visPhysics)
export(visRedraw)
export(visRemoveEdges)
export(visRemoveNodes)
export(visSave)
export(visSelectEdges)
export(visSelectNodes)
export(visSetData)
export(visSetOptions)
export(visSetSelection)
export(visStabilize)
export(visStartSimulation)
export(visStopSimulation)
export(visUnselectAll)
export(visUpdateEdges)
export(visUpdateNodes)
import(htmltools)
import(htmlwidgets)
importFrom(jsonlite,fromJSON)
importFrom(magrittr,"%>%")
importFrom(methods,findFunction)
importFrom(utils,browseURL)
importFrom(utils,getAnywhere)
